@@ -50,7 +50,7 @@ pub struct TaskProcess<'info> {
         bump = task.bump,
         has_one = daemon,
         constraint = task.status == TaskStatus::Pending @ ErrorCode::TaskNotPending,
-        constraint = task.execute_at <= clock.unix_timestamp @ ErrorCode::TaskNotDue,
+        constraint = task.exec_at <= clock.unix_timestamp @ ErrorCode::TaskNotDue,
         owner = crate::ID
     )]
     pub task: Account<'info, Task>,
@@ -68,10 +68,10 @@ pub fn handler(ctx: Context<TaskProcess>) -> ProgramResult {
     let worker = &mut ctx.accounts.worker;
 
     // Update task state.
-    if task.repeat_every > 0 {
-        let next_execute_at = task.execute_at.checked_add(task.repeat_every).unwrap();
-        if next_execute_at <= task.repeat_until {
-            task.execute_at = next_execute_at
+    if task.recurr > 0 {
+        let next_exec_at = task.exec_at.checked_add(task.recurr).unwrap();
+        if next_exec_at <= task.stop_at {
+            task.exec_at = next_exec_at
         }
     } else {
         task.status = TaskStatus::Executed;
